@@ -185,10 +185,12 @@ closure_finalize(gpointer  data,
     self->~Closure();
 }
 
-void
+bool
 gjs_closure_invoke(GClosure                   *closure,
+                   JS::HandleObject            this_obj,
                    const JS::HandleValueArray& args,
-                   JS::MutableHandleValue      retval)
+                   JS::MutableHandleValue      retval,
+                   bool                        return_exception)
 {
     Closure *c;
     JSContext *context;
@@ -198,11 +200,11 @@ gjs_closure_invoke(GClosure                   *closure,
     if (c->obj == nullptr) {
         /* We were destroyed; become a no-op */
         c->context = NULL;
-        return;
+        return false;
     }
 
     context = c->context;
-    JS_BeginRequest(context);
+    JSAutoRequest ar(context);
     JSAutoCompartment ac(context, c->obj);
 
     if (JS_IsExceptionPending(context)) {
@@ -212,18 +214,26 @@ gjs_closure_invoke(GClosure                   *closure,
     }
 
     JS::RootedValue v_closure(context, JS::ObjectValue(*c->obj));
-    if (!gjs_call_function_value(context,
-                                 /* "this" object; null is some kind of default presumably */
-                                 nullptr,
-                                 v_closure, args, retval)) {
+    if (!gjs_call_function_value(context, this_obj, v_closure, args, retval)) {
         /* Exception thrown... */
         gjs_debug_closure("Closure invocation failed (exception should "
                           "have been thrown) closure %p callable %p",
                           closure, c->obj.get());
-        if (!gjs_log_exception(context))
+        /* If an exception has been thrown, log it, unless the caller
+         * explicitly wants to handle it manually (for example to turn it
+         * into a GError), in which case it replaces the return value
+         * (which is not valid anyway) */
+        if (JS_IsExceptionPending(context)) {
+            if (return_exception)
+                JS_GetPendingException(context, retval);
+            else
+                gjs_log_exception(context);
+        } else {
+            retval.setUndefined();
             gjs_debug_closure("Closure invocation failed but no exception was set?"
                               "closure %p", closure);
-        goto out;
+        }
+        return false;
     }
 
     if (gjs_log_exception(context)) {
@@ -232,9 +242,7 @@ gjs_closure_invoke(GClosure                   *closure,
     }
 
     JS_MaybeGC(context);
-
- out:
-    JS_EndRequest(context);
+    return true;
 }
 
 bool
