@@ -61,8 +61,6 @@ gjs_foreign_load_foreign_module(JSContext *context,
     int i;
 
     for (i = 0; foreign_modules[i].gi_namespace; ++i) {
-        int code;
-        GError *error = NULL;
         char *script;
 
         if (strcmp(gi_namespace, foreign_modules[i].gi_namespace) != 0)
@@ -74,12 +72,11 @@ gjs_foreign_load_foreign_module(JSContext *context,
         // FIXME: Find a way to check if a module is imported
         //        and only execute this statement if isn't
         script = g_strdup_printf("imports.%s;", gi_namespace);
-        if (!gjs_context_eval((GjsContext*) JS_GetContextPrivate(context), script, strlen(script),
-                              "<internal>", &code,
-                              &error)) {
-            g_printerr("ERROR: %s\n", error->message);
+        JS::RootedValue retval(context);
+        if (!gjs_eval_with_scope(context, nullptr, script, strlen(script),
+                                 "<internal>", &retval)) {
+            g_critical("ERROR importing foreign module %s\n", gi_namespace);
             g_free(script);
-            g_error_free(error);
             return false;
         }
         g_free(script);
