@@ -61,6 +61,8 @@ bool      gjs_typecheck_is_object(JSContext       *context,
 void gjs_object_prepare_shutdown(void);
 void gjs_object_clear_toggles(void);
 void gjs_object_shutdown_toggle_queue(void);
+void gjs_object_context_dispose_notify(void    *data,
+                                       GObject *where_the_object_was);
 
 void gjs_object_define_static_methods(JSContext       *context,
                                       JS::HandleObject constructor,
