@@ -91,7 +91,7 @@ resolve_namespace_object(JSContext       *context,
 
     JSAutoRequest ar(context);
 
-    GjsAutoJSChar version(context);
+    GjsAutoJSChar version;
     if (!get_version_for_ns(context, repo_obj, ns_id, &version))
         return false;
 
@@ -113,7 +113,7 @@ resolve_namespace_object(JSContext       *context,
     if (error != NULL) {
         gjs_throw(context,
                   "Requiring %s, version %s: %s",
-                  ns_name, version?version:"none", error->message);
+                  ns_name, version ? version.get() : "none", error->message);
 
         g_error_free(error);
         return false;
@@ -161,16 +161,22 @@ repo_resolve(JSContext       *context,
              bool            *resolved)
 {
     Repo *priv;
-    GjsAutoJSChar name(context);
 
-    if (!gjs_get_string_id(context, id, &name)) {
+    if (!JSID_IS_STRING(id)) {
         *resolved = false;
         return true; /* not resolved, but no error */
     }
 
+    JSFlatString *str = JSID_TO_FLAT_STRING(id);
     /* let Object.prototype resolve these */
-    if (strcmp(name, "valueOf") == 0 ||
-        strcmp(name, "toString") == 0) {
+    if (JS_FlatStringEqualsAscii(str, "valueOf") ||
+        JS_FlatStringEqualsAscii(str, "toString")) {
+        *resolved = false;
+        return true;
+    }
+
+    GjsAutoJSChar name;
+    if (!gjs_get_string_id(context, id, &name)) {
         *resolved = false;
         return true;
     }
