@@ -37,10 +37,6 @@
 #include <windows.h>
 #endif
 
-#ifdef ENABLE_CAIRO
-# include <cairo.h>
-#endif
-
 /* Implementations of locale-specific operations; these are used
  * in the implementation of String.localeCompare(), Date.toLocaleDateString(),
  * and so forth. We take the straight-forward approach of converting
@@ -218,16 +214,6 @@ on_promise_unhandled_rejection(JSContext                    *cx,
                                                       std::move(stack));
 }
 
-static void
-shutdown(void)
-{
-    JS_ShutDown();
-
-#ifdef ENABLE_CAIRO
-    cairo_debug_reset_static_data();  /* for valgrind reports */
-#endif
-}
-
 #ifdef G_OS_WIN32
 HMODULE gjs_dll;
 static bool gjs_is_inited = false;
@@ -245,7 +231,7 @@ LPVOID    lpvReserved)
     break;
 
   case DLL_THREAD_DETACH:
-    shutdown();
+    JS_ShutDown ();
     break;
 
   default:
@@ -265,7 +251,7 @@ public:
     }
 
     ~GjsInit() {
-        shutdown();
+        JS_ShutDown();
     }
 
     operator bool() {
@@ -322,13 +308,14 @@ gjs_create_js_context(GjsContext *js_context)
         JS::ContextOptionsRef(cx).setExtraWarnings(true);
     }
 
-    if (!g_getenv("GJS_DISABLE_JIT")) {
+    bool enable_jit = !(g_getenv("GJS_DISABLE_JIT"));
+    if (enable_jit) {
         gjs_debug(GJS_DEBUG_CONTEXT, "Enabling JIT");
-        JS::ContextOptionsRef(cx)
-            .setIon(true)
-            .setBaseline(true)
-            .setAsmJS(true);
     }
+    JS::ContextOptionsRef(cx)
+        .setIon(enable_jit)
+        .setBaseline(enable_jit)
+        .setAsmJS(enable_jit);
 
     return cx;
 }
