@@ -33,6 +33,10 @@ G_BEGIN_DECLS
 JSObject *gjs_create_root_importer(JSContext          *cx,
                                    const char * const *search_path);
 
+bool gjs_import_native_module(JSContext       *cx,
+                              JS::HandleObject importer,
+                              const char      *name);
+
 G_END_DECLS
 
 #endif  /* __GJS_IMPORTER_H__ */
