@@ -228,3 +228,16 @@ describe('Cairo', function () {
         });
     });
 });
+
+describe('Cairo imported via GI', function () {
+    const giCairo = imports.gi.cairo;
+
+    it('has the same functionality as imports.cairo', function () {
+        const surface = new giCairo.ImageSurface(Cairo.Format.ARGB32, 1, 1);
+        void new giCairo.Context(surface);
+    });
+
+    it('has boxed types from the GIR file', function () {
+        void new giCairo.RectangleInt();
+    });
+});
