@@ -1,4 +1,6 @@
+const GLib = imports.gi.GLib;
 const Regress = imports.gi.Regress;
+const System = imports.system;
 
 describe('Introspected structs', function () {
     let struct;
@@ -229,6 +231,16 @@ describe('Introspected GObject', function () {
         obj.ownprop = 'foo';
         expect(obj.hasOwnProperty('ownprop')).toBeTruthy();
     });
+
+    // This test is not meant to be normative; a GObject behaving like this is
+    // doing something unsupported. However, we have been handling this so far
+    // in a certain way, and we don't want to break user code because of badly
+    // behaved libraries. This test ensures that any change to the behaviour
+    // must be intentional.
+    it('resolves properties when they are shadowed by methods', function () {
+        expect(obj.name_conflict).toEqual(42);
+        expect(obj.name_conflict instanceof Function).toBeFalsy();
+    });
 });
 
 describe('Introspected function length', function () {
@@ -261,3 +273,18 @@ describe('Introspected function length', function () {
         expect(Regress.TestObj.new_callback.length).toEqual(1);
     });
 });
+
+describe('Garbage collection of introspected objects', function () {
+    // This tests a regression that would very rarely crash, but
+    // when run under valgrind this code would show use-after-free.
+    it('collects objects properly with signals connected', function (done) {
+        function orphanObject() {
+            let obj = new Regress.TestObj();
+            obj.connect('notify', () => {});
+        }
+
+        orphanObject();
+        System.gc();
+        GLib.idle_add(GLib.PRIORITY_LOW, () => done());
+    });
+});
