@@ -88,10 +88,16 @@ test $? -eq 42
 report "System.exit(42) should exit with the correct exit code"
 
 # FIXME: should check -eq 42 specifically, but in debug mode we will be
-# hitting an assertion
-$gjs exit.js
-test $? -ne 0
-report "System.exit() should still exit across an FFI boundary"
+# hitting an assertion. For this reason, skip when running under valgrind
+# since nothing will be freed.
+echo "# VALGRIND = $VALGRIND"
+if test -z $VALGRIND; then
+    $gjs exit.js
+    test $? -ne 0
+    report "System.exit() should still exit across an FFI boundary"
+else
+    skip "System.exit() should still exit across an FFI boundary" "running under valgrind"
+fi
 
 # gjs --help prints GJS help
 $gjs --help >/dev/null
@@ -197,6 +203,9 @@ $gjs -c "Promise.resolve().then(() => { throw new Error(); });" 2>&1 | grep -q '
 report "unhandled promise rejection should be reported"
 test -z "$($gjs awaitcatch.js)"
 report "catching an await expression should not cause unhandled rejection"
+# https://gitlab.gnome.org/GNOME/gjs/issues/18
+$gjs -c "(async () => await true)(); void foobar;" 2>&1 | grep -q 'Script .* threw an exception'
+report "main program exceptions are not swallowed by queued promise jobs"
 
 # https://gitlab.gnome.org/GNOME/gjs/issues/26
 $gjs -c 'new imports.gi.Gio.Subprocess({argv: ["true"]}).init(null);'
