@@ -22,12 +22,17 @@
 
 #include <config.h>
 
+#include "gjs/jsapi-class.h"
 #include "gjs/jsapi-util-args.h"
 #include "gjs/jsapi-wrapper.h"
 #include <cairo.h>
 #include "cairo-private.h"
 
-GJS_DEFINE_PROTO_ABSTRACT("CairoSolidPattern", cairo_solid_pattern, JSCLASS_BACKGROUND_FINALIZE)
+static JSObject *gjs_cairo_solid_pattern_get_proto(JSContext *);
+
+GJS_DEFINE_PROTO_ABSTRACT_WITH_PARENT("SolidPattern", cairo_solid_pattern,
+                                      cairo_pattern,
+                                      JSCLASS_BACKGROUND_FINALIZE)
 
 static void
 gjs_cairo_solid_pattern_finalize(JSFreeOp *fop,
@@ -103,6 +108,8 @@ JSFunctionSpec gjs_cairo_solid_pattern_proto_funcs[] = {
     JS_FS_END
 };
 
+JSFunctionSpec gjs_cairo_solid_pattern_static_funcs[] = { JS_FS_END };
+
 JSObject *
 gjs_cairo_solid_pattern_from_pattern(JSContext       *context,
                                      cairo_pattern_t *pattern)
@@ -111,8 +118,10 @@ gjs_cairo_solid_pattern_from_pattern(JSContext       *context,
     g_return_val_if_fail(pattern != NULL, NULL);
     g_return_val_if_fail(cairo_pattern_get_type(pattern) == CAIRO_PATTERN_TYPE_SOLID, NULL);
 
+    JS::RootedObject proto(context, gjs_cairo_solid_pattern_get_proto(context));
     JS::RootedObject object(context,
-        JS_NewObject(context, &gjs_cairo_solid_pattern_class));
+        JS_NewObjectWithGivenProto(context, &gjs_cairo_solid_pattern_class,
+                                   proto));
     if (!object) {
         gjs_throw(context, "failed to create solid pattern");
         return NULL;
